import React, {useRef, useState} from 'react';
import {NavLink, useHistory} from 'react-router-dom';
import './Registration.css';
import ExistingLoginError from "../../Components/RegistrationError/ExistingLoginError";
import ConfirmPasswordError from "../../Components/RegistrationError/ConfirmPasswordError";
import {connect} from "react-redux";
import {actionRegistrations} from "../../Actions/action_registration";
import Button from "../../Components/Button/Button";
import {actionUserErrorReset} from "../../Redux/error_reducer";

const Registration = ({onRegistration, existingUser, existingUserErrorReset, checkLogin, loginNetworkError}) => {

    const history = useHistory();

    if (checkLogin) {
        history.push('/profile')
    }

    if (localStorage.authToken) {
        history.push('/profile')
    }

    if (loginNetworkError) {
        history.push('/404')
    }

    const loginRef = useRef(null)
    const pasRef = useRef(null)
    const confirmPasRef = useRef(null)

    const [login, setLogin] = useState("")
    const [password, setPassword] = useState("")
    const [confirmPassword, setConfirmPassword] = useState("")
    const [show, setShow] = useState(false)

    const isRegistrationValid = () => {
        if(!login || !password || !confirmPassword) return false
        if(password !== confirmPassword) return false   // indexOf
        else return true
    }

    const registrationCallback = () => {
        if(isRegistrationValid()) {
            onRegistration(login, password)
        }
        else {
            setShow(true)
        }
    }

    return (
        <div className='registration-wrapper'>
            <input
                value={login}
                placeholder="Login"
                ref={loginRef}
                onChange={(e) => {
                    setLogin(e.target.value);
                    existingUserErrorReset();
                }}
            />
            <input
                value={password}
                placeholder="Password"
                ref={pasRef}
                onChange={(e) => setPassword(e.target.value)}
                type="password"
            />
            <input
                value={confirmPassword}
                placeholder="Confirm Password"
                ref={confirmPasRef}
                onChange={(e) => setConfirmPassword(e.target.value)}
                type="password"
            />

            <Button
                name='Registration'
                isValid={isRegistrationValid()}
                callback={registrationCallback}
            />

            <nav className='registration-wrapper__link'>
                <NavLink to="/login">Login</NavLink>
            </nav>

            {existingUser && <ExistingLoginError/>}
            {show && <ConfirmPasswordError/>}
        </div>
    )
}

const CRegistration = connect(
    (state) => ({
        existingUser: state?.errors?.existingUserError,
        checkLogin: state.auth.isLogin,
        loginNetworkError: state?.errors?.loginNetworkError
    }), {
    onRegistration: actionRegistrations,
    existingUserErrorReset: actionUserErrorReset
})(Registration)

export default CRegistration